{% extends 'bp_util_base.html' %}
{% block about %}
<li class="active"><a href="{{url_for('eisenutil_bp.about')}}">About</a>
    {% endblock %}
    {% block content %}

<div class="divFadeIn">

    <div class="divBarToolsBg">
        <div class="divToolsBgColor">
            <div class="divToolsBodyText">
                <p> This App runs on Python Flask HTTP server and SQLite on your device.</p>
                <p> Flask Web Server connects to the radio server in behalf of you. Your browser connects to Flask.</p>
                <p> Closing your browser does not disconnect the server listen (buffer discarded) nor streaming connection.</p>
                <p> First Internet Radio App that can: </p>
                <ul>
                    <li>use internet audio streams to animate HTML and SVG Elements. See Project description</li>
                    <li>monitor recordings by writing editable lists. Export and import lists on multiple devices.</li>
                </ul>


                <details>
                    <summary>
                        <h5>► Help</h5>
                    </summary>
                        <dl>
                            <dt>CPU utilisation select</dt>
                            <dd>
                                Stops most of the animations. Saves energy. Turns fun into sadness.<br>
                                Annotation. A browser stops and saves the state of animations on hiding the browser tab.<br>
                                The animation sleeps to preserve CPU and will not eat your Notebook battery.<br>
                                You can disable all animations in Tools/config menu also.
                            <dt>Monitor Recordings</dt>
                            <dd>
                                Delete unwanted files only once.<br>
                                Eisenradio writes slices of the data stream to disk and the title (metadata) into a list.<br>
                                Skips writing if list matches.
                                Delete titles you want again or erase the whole list via Tools menu or Edit button.<br>
                           </dd>
                            <dt>Playlist</dt>
                            <dd>
                                Folders are playlist. Fill a folder with favourite titles, or cherry-pick in there.<br>
                                Mp3, aac, what the browser plays. The file list appears on the very top of the page.<br>
                                Has forward and backward title controls on the console. It will get stuck with defective files.
                           </dd>
                            <dt>Timer</dt>
                            <dd> Disconnects all radio streams and recordings.<br>
                                 Ends aac file writings graceful, although the last file is probably incomplete.<br>
                                 It will not affect (stuck) the playlist. See aac repair.
                           </dd>
                            <dt>acp and aac(plus) repair</dt>
                            <dd>Browser stops with a silent error, if file start or file end is defective.<br>
                                Selected files are hold in RAM and copied to the radios parent folder after repair.<br>
                                Incomplete data sequences are cut from start and end of file. Mini files are not written ().
                            </dd>
                            <dt>Internet radio won't play?</dt>
                            <dd>Internet radios change bit rates, stream file types, user limits, or split into multiple streams.<br>
                                Look for URL change. "Edit" can guide you to a ShoutCast or IceCast side where updated information may be available.
                                Append /sid=1 to the URL. As an example: http://85.195.88.149:11810/<b>sid=1</b>.<br>
                            </dd>
                            <dt>Hunt for your preferred Radio URL.</dt>
                            <dd>
                                <a href="{{ url_for('eisenutil_bp.static', filename='/images/getaradiourl.svg') }}">
                                    A post-it for you.
                                </a>
                            </dd>

                            <dt>Get radio URLs</dt>
                            <dd>
                                Get radio urls at Shoutcast 'Directory', take a playlist and open it with a text editor."
                                <a href="https://duckduckgo.com/?q=http%3A%2F%2Fdirectory.shoutcast.com%2F&t=hc&va=o&ia=web">
                                    DuckDuckGo ShoutCast</a>
                                <br>
                                IceCast is another software used to stream radio content to users.
                                <a href="https://duckduckgo.com/?q=http%3A%2F%2Fdir.xiph.org%2Fgenres&t=hc&va=o&ia=web">
                                    DuckDuckGo IceCast</a>
                                <br>
                                German wiki.ubuntuusers.de tells you how to get even more stream urls from international search engines (use Chrome browser translation).
                                <a href="https://wiki.ubuntuusers.de/Internetradio/Streamadressen_ermitteln/">
                                    wiki.ubuntuusers.de</a>
                            </dd>

                        </dl>

                </details>
            </div>
        </div>
    </div>

    <div class="divToolsSpacer">
    </div>

    <div class="divBarToolsBg">
        <div class="divToolsBgColor">
            <div class="divToolsBodyText">

                <form id="formABC" action="{{ url_for('eisenutil_bp.about') }}" method="post">
                    <div class="form-group">
                        {% if is_browser_on %}{% set browser = "ON" %}{% endif -%}
                        {% if not is_browser_on %}{% set browser = "OFF" %}{% endif -%}

                        <input class="btn btn-primary btn-sm" type="submit" value="{{browser}}" name="browser" id="12">
                        <label for="12"><b>Browser auto start</b></label>

                    </div>
                </form>
                <details>
                    <summary>
                        <h5>► Where is my database?</h5>
                    </summary>
                    <p></p>
                    <p style="color:brown;font-size:14px;">{{ db_path }}</p>
                    <p>Delete the database if you uninstall, or reinstall. An existing database will not be overwritten.</p>
                    <p>Android user delete the /Music/Eisenradio/eisenradio_android.db, or the folder.</p>
                    <p>Android is subject to change, since they implement more security levels.
                        The current setup must write the database in the users app folder, where the user has no access!</p>
                    <p>This will lead to a (future) new database entry and feature button, where we can choose to delete the database for
                        re-installation.</p>

                </details>
            </div>
        </div>
    </div>

    <div class="divToolsSpacer">
    </div>

    <div class="divBarToolsBg">
        <div class="divToolsBgColor">
            <div class="divToolsBodyText">
                    <p>Thanks to "franks laboratory" on YouTube. His tutorials have helped to jump from painting a canvas to SVG/HTML animation.</p>
                    <p>License on the python package server <a href="https://pypi.org/project/eisenradio/"> project eisenradio</a></p>
                    <p><a href="https://github.com/44xtc44/EisenRadio/issues"> Report an issue</a></p>
                    <p><a href="https://github.com/44xtc44/eisenradio"> Github repository</a></p>
                    <p>All images, except python, &#169; 2022 René Horn</p>
            </div>
        </div>
    </div>

    <div class="divToolsSpacer">
    </div>

    <div class="divBarToolsBg">
        <div class="divToolsBgColor">
            <div class="divToolsBodyText">
                <div id="divPythonPoweredImage">
                    <img src="{{ url_for('eisenutil_bp.static', filename='/images/python-powered-w-100x40.png') }}"
                         alt="https://www.python.org/"
                         style="width:100px;height:40px;">
                </div>
            </div>
        </div>
    </div>

    <div class="divToolsSpacer">
    </div>
    <hr>

</div>
    {% endblock %}