<!doctype html>
<html lang="en">
<head>
    <!-- Required meta tags -->
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

    <!-- Jquery Prod BEFORE BOOTsh-->
    <script type="text/javascript"
            src="{{ url_for('eisenutil_bp.static', filename='/jquery/jquery-3.6.0.min.js') }}">
    </script>

    <!-- google fonts -->
    <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Roboto">
    <link rel="stylesheet" href="{{ url_for('eisenutil_bp.static', filename= 'css/style.css') }}">
    <link rel="icon" type="image/x-icon" href="{{ url_for('eisenutil_bp.static', filename='favicon.ico') }}">

    <title>{% block title %} {% endblock %}</title>
</head>
<body>
<noscript>Please enable JavaScript in your browser</noscript>

            <!-- url_for blueprint-name.route -->
<div id="divTopNav">
  <section class="top-nav">
    <div id="menuHome" class="toggleIcon"
         onclick="javascript:location.href='{{url_for('eisenhome_bp.index')}}'">
        EisenRadio
    </div>
    <input id="menu-toggle" type="checkbox" />
    <label class='menu-button-container' for="menu-toggle">
    <div class='menu-button'></div>
  </label>
    <ul class="menu">
        {% block new_radio %}
        <li class="toggleIcon" onclick="javascript:location.href='{{url_for('eisenutil_bp.create')}}'">New
        {% endblock %}</li>

        {% block save_radio %}
        <li class="toggleIcon" onclick="javascript:location.href='{{url_for('eisenutil_bp.save')}}'">Save
        {% endblock %}</li>

        {% block tools %}
        <li class="toggleIcon" onclick="javascript:location.href='{{url_for('eisenutil_bp.tools')}}'">Tools
        {% endblock %}</li>

        {% block about %}
        <li class="toggleIcon" onclick="javascript:location.href='{{url_for('eisenutil_bp.about')}}'">About
        {% endblock %}</li>
    </ul>
  </section>
</div>

<div>
    <div class="divLoaderAnimationDialog" id="divLoaderAnimationThreeNiceGuys">
        <div class="divCenterAnimationLoaderItems">
            <div class="loaderAnimation">
              <div class="inner one"></div>
              <div class="inner two"></div>
              <div class="inner three"></div>
            </div>
        </div>
    </div>
</div>

<div class="container">
    <footer></footer>
</div>

<div class="container">
    {% for category, message in get_flashed_messages(with_categories=true) %}
    <div class="alert alert-{{ category }}">{{ message }}</div>
    {% endfor %}

    {% block content %} {% endblock %}
</div>

<script type="text/javascript"
        src="{{ url_for('eisenutil_bp.static', filename='/jquery/jquery-3.6.0.min.js') }}"></script>
<script type="text/javascript" src="{{ url_for('eisenutil_bp.static', filename='/js/bp_util.js') }}"></script>

</body>
</html>
