{% extends 'bp_util_base.html' %}
{% block save_radio %}
<li class="active"><a href="{{url_for('eisenutil_bp.save')}}">Save</a>
    {% endblock %}
    {% block content %}


<div class="divFadeIn">

    <div class="divBarToolsBg">
        <div class="divToolsBgColor">
            <div class="divToolsBodyText">
                <p>The parent folder of your radio stations.</p>
                <hr>
                <div class="form-group">
                    <form method="post">
                        <label for="Path_Save_To">Folder Name </label>

                        <input type="text" name="Path_Save_To"
                                   class="form-control"
                                   placeholder="{{save_to}}"
                                   value={{save_to}}
                                   id="Path_Save_To"
                                   required size="100">

                        <div class="form-group">
                            <input type="file"
                                   id="windowsPathClick"
                                   style="display: none;">
                            <div id="div_caller_windowsPathClick">
                                <span id="caller_windowsPathClick"
                                      onclick="autoClickButton('caller_windowsPathClick_.');">

                                click
                                </span>
                            </div>
                            <pre id="preSave">(Linux) /home/user_name/Downloads
                                <br>(Android) /storage/emulated/0/Music/Eisenradio
                                <br>(Windows) Click: Copy a directory name
	            	        </pre>

                        </div>
                        <div class="form-group">
                            <button type="submit" class="btn btn-primary btn-sm">Submit</button>
                        </div>
                    </form>

                </div>
            </div>
        </div>
    </div>

</div>
<hr>
    {% endblock %}