{% extends 'bp_util_base.html' %}

{% block content %}
<h3 xmlns="http://www.w3.org/1999/html">{% block title %} Blacklists {% endblock %}</h3>
<p>Enable blacklists in "Tools".</p>
<p>A blacklist is a list of title "names". The recorder refuses to write if the title name is found in the list.</p>
<p>Delete a title name from the list to record a file again.</p>
<p>Skip count is the number of title writes skipped by the recorder during an app session.</p>
<hr>
<div class="blacklist_div">
    <div><span class="flex-item">Skip count: {{skip_count}}</span></div>
    <hr>
    <div class="divFlex">
            {% for radio in radios_dict.values()%}
        <div class="divItemWrap"
             onclick="javascript:location.href='{{url_for('eisenutil_bp.tools_radio_blacklist', radio_name=radio) }}'">
            <span>
                {{radio}} {{radio_blacklist_count[radio]}}
            </span>
        </div>
        {% endfor %}
    </div>
</div>
{% endblock %}

