@import url(https://fonts.googleapis.com/css?family=Raleway);
* {
  font-family: "Raleway";
  box-sizing: border-box;
}
html {
  -webkit-text-size-adjust: none;
}
:root {
    --background-color: #ccc;
    --hr-color: #eee;
    --border-color: #fff;
    --ghettoDataColor: ivory;
    --customTxtColor: black;
    --timerProgressOpacity:1;
}
body {
/* measured by getBodyColor() */
  color: magenta;
  background: var(--background-color);
  font-family: roboto, arial, sans-serif;
}

#divTopNav {
  position:relative;
  height: 30px;
  z-index:10000;
}
.top-nav {
  display: flex;
  flex-direction: row;
  align-items: center;
  justify-content: space-between;
  background-color: #00BAF0;
  background: linear-gradient(to left, #f46b45, #eea849);
  /* W3C, IE 10+/ Edge, Firefox 16+, Chrome 26+, Opera 12+, Safari 7+ */
  color: #FFF;
  height: 25px;
  padding: 1em;
}

.menu {
  display: flex;
  flex-direction: row;
  list-style-type: none;
  margin: 0;
  padding: 0;
}

.menu > li {
  margin: 0 1rem;
  overflow: hidden;
}

.menu-button-container {
  display: none;
  height: 100%;
  width: 30px;
  cursor: pointer;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}

#menu-toggle {
  display: none;
}

.menu-button,
.menu-button::before,
.menu-button::after {
  display: block;
  background-color: #fff;
  position: absolute;
  height: 4px;
  width: 30px;
  transition: transform 400ms cubic-bezier(0.23, 1, 0.32, 1);
  border-radius: 2px;
}

.menu-button::before {
  content: '';
  margin-top: -8px;
}

.menu-button::after {
  content: '';
  margin-top: 8px;
}

#menu-toggle:checked + .menu-button-container .menu-button::before {
  margin-top: 0px;
  transform: rotate(405deg);
}

#menu-toggle:checked + .menu-button-container .menu-button {
  background: rgba(255, 255, 255, 0);
}

#menu-toggle:checked + .menu-button-container .menu-button::after {
  margin-top: 0px;
  transform: rotate(-405deg);
}

@media (max-width: 700px) {
  .menu-button-container {
    display: flex;
  }
  .menu {
    position: absolute;
    top: 0;
    margin-top: 50px;
    left: 0;
    flex-direction: column;
    width: 100%;
    justify-content: center;
    align-items: center;
  }
  #menu-toggle ~ .menu li {
    height: 0;
    margin: 0;
    padding: 0;
    border: 0;
    transition: height 400ms cubic-bezier(0.23, 1, 0.32, 1);
  }
  #menu-toggle:checked ~ .menu li {
    border: 1px solid #333;
    height: 2.5em;
    padding: 0.5em;
    transition: height 400ms cubic-bezier(0.23, 1, 0.32, 1);
  }
  .menu > li {
    display: flex;
    justify-content: center;
    margin: 0;
    padding: 0.5em 0;
    width: 100%;
    color: white;
    background-color: #222;
  }
  .menu > li:not(:last-child) {
    border-bottom: 1px solid #444;
  }
}
#radioContainer {
  position:relative;
  height: 576px;
  width: 720px;
  display:none;
  margin-top:4px;
}
#divFrameRight {

}
#nextBtn {
  display:none;
}
#prevBtn {
  display:none;
}
#customImg {
  position:absolute;
  left:730px;
  width:100%;
  display:none;
}
#customTxt {
  position:absolute;
  left:730px;
  width:100%;
  display:none;
}
#divMonitorCanvas {
/* accommodates .stageMonitor class, stacked canvas */
  position:absolute;
  transform: scale(1.0,1.0);
  display:block;
}
.stageMonitor {
  position: absolute;
  left:0em;
}
#divA1AirCraft {
  display:none;
  position:absolute;
  top:5em;
  left:350px;
  min-height:2em;
  min-width:2em;

  z-index:10010;
}
.divDragRopeA1AirCraft {
  display:block;
  position:absolute;
  top:2em;
  left:250px;
  min-height:2em;
  min-width:2em;
  z-index:2;
}

.divSvgScrewHeadBottomLeft {
  display: block;
  position: absolute;
  z-index: 2;
  bottom: 2.5em;
  left: 0em;
  max-width: 1em;
  max-height: 1em;
}
.divSvgScrewHeadTopRight {
  display: block;
  position: absolute;
  z-index: 2;
  top: 0em;
  right: 2.3em;
  max-width: 1em;
  max-height: 1em;
}
.divSvgGlasBreakTopRight {
  display: block;
  position: absolute;
  z-index: 1;
  top: -1.75em;
  right: 4.8em;
  max-width: 1em;
  max-height: 1em;
}
.divSvgScrewHeadTopLeft {
  display: block;
  position: absolute;
  z-index: 2;
  top: 0em;
  left: 0.2em;
  max-width: 1em;
  max-height: 1em;
}
.divSvgScrewHeadBottomRight {
  display: block;
  position: absolute;
  z-index: 2;
  bottom: 2.5em;
  left: 670px;
  max-width: 1em;
  max-height: 1em;
}
#recorderIsOn {
  display: none;
  position: absolute;
  z-index: 2;
  bottom: 30px;
  left: 355px;
}
#recordImage {
  width:75px;
}
.divHeader {
/* box for radio station header info, url, name
*/
  position:absolute;
  top:-.5em;
  left:5em;
  font-family: Roboto, Helvetica, Arial, sans-serif;
  font-weight: 500;
  text-align: left;
  font-size: 120%;
  z-index:3000;
}
#icy_name {
  color: var(--ghettoDataColor);
  text-shadow: 1px 1px 2px red, 0 0 1em blue, 0 0 0.2em blue;
}
#request_icy_url {
  color:BlanchedAlmond;
  cursor:pointer;
  text-shadow: 1px 1px 2px green, 0 0 1em blue, 0 0 0.2em blue;
}
.toggleIcon {
  cursor:pointer;
}
.boldText {
  font-weight: 600;
}
#titleDisplay {
  color: var(--ghettoDataColor);
  font-family: Roboto, Helvetica, Arial, sans-serif;
  font-weight: 500;
  text-align: left;
  font-size: 100%;
  display: inline-block;
  text-shadow: 1px 1px 2px red, 0 0 .1em blue, 0 0 0.2em blue;
}
.divPlayButtons {
  position: absolute;
  display:inline-block;
  min-width:200px;
  min-height:0px;
  left:8em;
  bottom:30px;
  border-radius: 1.5em;
  border-radius:1.5em;
  border: 2px solid rgba(255,255,255,0.1);
  box-shadow:30px 30px 35px rgba(0,0,0,0.25);
  z-index: 2000;
  color: black;
}
#audioControls {
  display:none;
  position:absolute;
  bottom:30px;
  left:1em;
  min-height:60px;
  z-index: 2002;
  background-color:rgba(255, 99, 71,0.9);
  border-radius:.5em;
  border: 2px solid rgba(255,255,255,0.1);
  box-shadow:30px 30px 35px rgba(0,0,0,0.25);
  color: black;
}
#audioSlider {
  bottom:0px;
  left:0px;
}
.spanX {
  position: absolute;
  top: -5px;
  right: -2px;
  font-size: 18px;
  cursor:pointer;
  background-color:rgba(255, 99, 71,0.9);
  border-radius:.1em;
  border: 2px solid rgba(255,255,255,0.1);
  box-shadow:30px 30px 35px rgba(0,0,0,0.25);
}
.pElemX {
  text-align:end;
}
#console {
  display:none;
  position:absolute;
  top:.5em;
  left:.5em;
  max-width:400px;
  background-color:rgba(255, 99, 71,0.9);  /* rgba(102, 205, 170,0.9) */
  z-index: 11000;
  border-radius:.5em;
  border: 2px solid rgba(255,255,255,0.1);
  box-shadow:30px 30px 35px rgba(0,0,0,0.25);
  color: black;
}
#wrapRecordView {
  display:none;
  position:absolute;
  top:2em;
  left:0em;
  width:80%;
  border-radius:.5em;
  border: 2px solid rgba(255,255,255,0.1);
  box-shadow:30px 30px 35px rgba(0,0,0,0.25);
  color: black;
  background-color:ivory;
}
#divRecordView {
  width:90%;
  height:100%;
  overflow:auto;
}
#spanRecordView {
  background-color:ivory;
}
#divMeasurementsUpper {
  display: block;
  position: absolute;
  z-index: 2000;
  min-width:.2em;
  bottom:50px;
  left:600px;
}
.ghettoData {
  /* ms, suffix, bit rate */
  /* color: #4195fc; */
  color: var(--ghettoDataColor);
  font-family: Roboto, Helvetica, Arial, sans-serif;
  font-weight: 500;
  width: 5em;
  text-align: left;
  font-size: 130%;
  margin-left: 1.3em;
  margin-top: 0.5em;
  display: block;
  /*text-shadow:0px 3px 4px #333333; */
}
.boxSecondaryAction {
  margin:.75em;
}
.quickView {
  font-size:110%;
  font-family: Roboto, Verdana, Arial;
  background-color:papayaWhip;
}
#quickListen {
  background-color:lightYellow;
  border: 2px solid rgba(255,255,255,0.1);
  box-shadow:30px 30px 35px rgba(0,0,0,0.25);
}
#quickRecord {
  background-color:lightYellow;
  border: 2px solid rgba(255,255,255,0.1);
  box-shadow:30px 30px 35px rgba(0,0,0,0.25);
}
#quickEdit {
  background-color:lightYellow;
}
#timeRecordSelectAll {
  background-color:lightYellow;
}
.divRecorderList {
  margin:0.5em;
  font-size:110%;
  font-family: Roboto, Helvetica, Arial, sans-serif;
  border-radius:.5em;
  border: 2px solid rgba(255,255,255,0.1);
  box-shadow:30px 30px 35px rgba(0,0,0,0.25);
  background-color:ivory;
}
#playlist {
  padding:.5em;
  display:none;
}
#divPlayListShow {
  font-size:100%;
}
.divCustomImg {
  padding:.5em;
}
.divCustomTxt {
  color: var(--customTxtColor);
  font-family: Roboto, Helvetica, Arial;
  font-weight: 300;
  font-size:110%;
  text-align: left;
  padding:.5em;
}
#buoyMenu {
  position:absolute;
  width:4em;
  height:5em;
  bottom:2em;
  left:3em;
  cursor:pointer;
}
#progressbarTimer {
  background-color: #fffdd0;
  border-radius: 13px;
  padding: 3px;
}
#progressbarTimerRuner {
  background-color: orange;
  width: 10%;
  height: 18px;
  border-radius: 10px;
  font-family: Roboto, Helvetica, Arial;
  font-weight: 500;
  font-size:100%;
}

.audioIcon {
  font-size:200%;
}
#toggleAnimals {
  font-size:200%;
  max-width:60px;
}
#toggleAnalyzer {
  font-size:200%;
  max-width:60px;
}
#hamburgerImage {
  width:60px;
  padding-top:4px;
  padding-left:15px;
}
#cpuImage {
  width:60px;
}
#blacklistImage {
  width:60px;
}

.divFlex {
  /* We first create a flex layout context */
  display: flex;

  /* Then we define the flow direction
     and if we allow the items to wrap
   * Remember this is the same as:
   * flex-direction: row;
   * flex-wrap: wrap;
   */
  flex-flow: row wrap;

  /* Then we define how is distributed the remaining space */
  justify-content: center;

  padding: 0px;
  margin:0 auto;
  margin-top:10px;
  list-style: none;
}
.flex-item {
  background: tomato;
  padding: 6px;
  margin: 6px;
  width: 75px;
  height: 75px;
  color: lightYellow;
  font-family: Roboto, Helvetica, Arial;
  font-weight: bold;
  text-align: center;
  cursor:pointer;
  border: 1px solid #aaa;
  box-shadow: 0 1px 0 1px rgba(0,0,0,.04);
}

.fontSize125 {
  font-size: 125%;
}
.fontSize150 {
  font-size: 150%;
}
.fontSize200 {
  font-size: 200%;
}

select {
    -moz-appearance: none;
    -webkit-appearance: none;
    appearance: none;
    background-color: #fff;
    background-repeat: no-repeat;
    background-position: right .7em top 50%, 0 0;
    background-size: .45em auto;
}
.select-css {
	display: block;
	font-size: normal;

	font-weight: bold;
	color: #444;
	line-height: 1.2;
	padding: .4em 1.4em .5em .8em;
	width: 100%;
	max-width: 100%;
	box-sizing: border-box;
	margin: 0;
	border: 1px solid #aaa;
	box-shadow: 0 1px 0 1px rgba(0,0,0,.04);
	border-radius: .5em;
	-moz-appearance: none;
	-webkit-appearance: none;
	appearance: none;
	background-color: #fff;
	background-image: url('data:image/svg+xml;charset=US-ASCII,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20width%3D%22292.4%22%20height%3D%22292.4%22%3E%3Cpath%20fill%3D%22%23007CB2%22%20d%3D%22M287%2069.4a17.6%2017.6%200%200%200-13-5.4H18.4c-5%200-9.3%201.8-12.9%205.4A17.6%2017.6%200%200%200%200%2082.2c0%205%201.8%209.3%205.4%2012.9l128%20127.9c3.6%203.6%207.8%205.4%2012.8%205.4s9.2-1.8%2012.8-5.4L287%2095c3.5-3.5%205.4-7.8%205.4-12.8%200-5-1.9-9.2-5.5-12.8z%22%2F%3E%3C%2Fsvg%3E'),
	/* linear-gradient(to bottom, #ffffff 0%,#e5e5e5 100%); */
	background-repeat: no-repeat, repeat;
	background-position: right .7em top 50%, 0 0;
	background-size: .65em auto, 100%;
}
.select-css::-ms-expand {
	display: none;
}
.select-css:hover {
	border-color: #888;
	cursor:pointer;
}
.select-css:focus {
	border-color: #aaa;
	box-shadow: 0 0 1px 3px rgba(59, 153, 252, .7);
	box-shadow: 0 0 0 3px -moz-mac-focusring;
	color: #222;
	outline: none;
}
.select-css option {
	font-weight:normal;
}